==> sx-0.4.0.tar.gz: sx-0.4.0/sx/actions/export/systemd.py <==
import os
import shutil
from sx.utils import sort
from sx.utils import compile_command
from sx.utils import get_package_root


def get_command(data):
    tokens = data.start.split()
    command = ' '.join([shutil.which(tokens[0]), *tokens[1:]])

    return compile_command(command, data)


def export_target(name, services, path):
    with open(os.path.join(path, name), 'w') as stream:
        stream.write('[Unit]\n')
        stream.write('After = network.target\n')
        stream.write('Wants = {}\n\n'.format(' '.join(services)))
        
        stream.write('[Install]\n')
        stream.write('WantedBy = multi-user.target\n')


def export_service(name, service_name, target, user, data, dependencies, path):
    with open(os.path.join(path, service_name), 'w') as stream:
        stream.write('[Unit]\n')
        if len(dependencies) == 0:
            stream.write('After = network.target\n')
        else:
            stream.write('After = {}\n'.format(' '.join(dependencies)))
        stream.write('PartOf = {}\n'.format(target))
        stream.write('Description = {}\n\n'.format(data.description))

        stream.write('[Service]\n')
        stream.write('User = {}\n'.format(user))
        if 'niceness' in data:
            stream.write('Nice = {}\n'.format(data.niceness))
        stream.write('ExecStartPre = /bin/sleep 2\n')
        stream.write('Environment = START_METHOD=SYSTEMD')
        stream.write('ExecStart = {}\n'.format(get_command(data)))
        stream.write('WorkingDirectory = {}\n\n'.format(os.path.abspath(get_package_root(name))))
        
        stream.write('[Install]\n')
        stream.write('WantedBy = {}\n'.format(target))


def export(settings, args):
    service_names = []
    path = os.path.join('manifests', 'systemd')
    target_name = settings.application.metadata.name.lower().replace(' ', '-')


    if os.path.exists(path):
        shutil.rmtree(path, ignore_errors=True)
    
    os.makedirs(path)
    for name, package_data in settings.application.packages:
        service_name = target_name + '-' + name + '.service'
        dependencies = [
            target_name + '-' + dependency + '.service'
            for dependency in package_data.dependencies
        ]

        service_names.append(service_name)

        export_service(name, service_name, target_name + '.target', args.user, package_data, dependencies, path)
    export_target(target_name + '.target', service_names, path)

==> sx-0.4.2.tar.gz: sx-0.4.2/sx/actions/export/systemd.py <==
import os
import shutil
from sx.utils import sort
from sx.utils import compile_command
from sx.utils import get_package_root


def get_command(data):
    tokens = data.start.split()
    command = ' '.join([shutil.which(tokens[0]), *tokens[1:]])

    return compile_command(command, data)


def export_target(name, services, path):
    with open(os.path.join(path, name), 'w') as stream:
        stream.write('[Unit]\n')
        stream.write('After = network.target\n')
        stream.write('Wants = {}\n\n'.format(' '.join(services)))
        
        stream.write('[Install]\n')
        stream.write('WantedBy = multi-user.target\n')


def export_service(name, service_name, target, user, data, dependencies, path):
    with open(os.path.join(path, service_name), 'w') as stream:
        stream.write('[Unit]\n')
        if len(dependencies) == 0:
            stream.write('After = network.target\n')
        else:
            stream.write('After = {}\n'.format(' '.join(dependencies)))
        stream.write('PartOf = {}\n'.format(target))
        stream.write('Description = {}\n\n'.format(data.description))

        stream.write('[Service]\n')
        stream.write('User = {}\n'.format(user))
        if 'niceness' in data:
            stream.write('Nice = {}\n'.format(data.niceness))
        stream.write('ExecStartPre = /bin/sleep 2\n')
        stream.write('Environment =START_METHOD=SYSTEMD\n')
        stream.write('ExecStart = {}\n'.format(get_command(data)))
        stream.write('WorkingDirectory = {}\n\n'.format(os.path.abspath(get_package_root(name))))
        
        stream.write('[Install]\n')
        stream.write('WantedBy = {}\n'.format(target))


def export(settings, args):
    service_names = []
    path = os.path.join('manifests', 'systemd')
    target_name = settings.application.metadata.name.lower().replace(' ', '-')


    if os.path.exists(path):
        shutil.rmtree(path, ignore_errors=True)
    
    os.makedirs(path)
    for name, package_data in settings.application.packages:
        service_name = target_name + '-' + name + '.service'
        dependencies = [
            target_name + '-' + dependency + '.service'
            for dependency in package_data.dependencies
        ]

        service_names.append(service_name)

        export_service(name, service_name, target_name + '.target', args.user, package_data, dependencies, path)
    export_target(target_name + '.target', service_names, path)
